@@ -36,7 +36,10 @@ def plywood(input, context={}, **options):
 
 class Plywood(object):
     def __init__(self, input):
-        self.input = unicode(input, 'utf-8')
+        if isinstance(input, unicode):
+            self.input = input
+        else:
+            self.input = unicode(input, 'utf-8')
         self.buffer = Buffer(self.input)
         self.output = ''
         self.block_indent = None
